# =========================================================================
# Licensed Materials - Property of IBM
# "Restricted Materials of IBM"
# (C) Copyright IBM Corp. 2005. All Rights Reserved
# 
# DISCLAIMER: 
# The following [enclosed] code is sample code created by IBM 
# Corporation.  This sample code is not part of any standard IBM product 
# and is provided to you solely for the purpose of assisting you in the 
# development of your applications.  The code is provided 'AS IS', 
# without warranty of any kind.  IBM shall not be liable for any damages 
# arising out of your use of the sample code, even if they have been 
# advised of the possibility of such damages.
# =========================================================================

# This is a shell script which configures
# environment variables for the Java VM.
# Variables must be exported to be seen by the JZOS launcher.
#
# This file must be customized for each installation, and placed in
# an accessible directory, such as /etc.
#
# Please refer the JZOS User's Guide, "Configuring Environment Variables" 
# for more information.

# The following shell variables can/may be set to control this script:
# APP_HOME (required)  - location of application class and jar files 
# JAVA_HOME (opt)      - if set, overrides java install home
# JZOS_HOME (opt)      - if set, overrides jzos install home 
# DB2_HOME  (opt)      - if set, overrides DB2 install home
# JAVA_MIN_HEAP (opt)  - if set, overrides java -Xms<min heap>
# JAVA_MAX_HEAP (opt)  - if set, overrides java -Xmx<max heap>

# Some options to speed up shell script
export _BPX_SHAREAS=YES
export _BPX_SPAWN_SCRIPT=YES

# Save $JAVA_HOME if set
JH="$JAVA_HOME"

# If /etc/profile is not run, then you must configure required system environment variables  
. /etc/profile

set -x

# Restore $JAVA_HOME in case it was set by /etc/profile
if [ -n "$JH" ] ; then
  JAVA_HOME=$JH
fi
 
# >>> Customize by changing <JZOS_HOME> to the installation JZOS home directory
if [ -z "$JZOS_HOME" ] ; then
  export JZOS_HOME=<JZOS_HOME>
fi 

# >>> Customize by changing <JAVA_HOME> to the installation Java home directory
if [ -z "$JAVA_HOME" ] ; then
  export JAVA_HOME=<JAVA_HOME>
fi 

# >>> Customize by changing <DB2_HOME> to the installation DB2 home directory
# >>> remove this if you don't want DB2 environment configured
if [ -z "$DB2_HOME" ] ; then
  DB2_HOME=<DB2_HOME>
fi 

# Configure PATH and LIBPATH...
export PATH=/bin:"$JAVA_HOME"/bin:

LIBPATH=/lib:/usr/lib:"$JAVA_HOME"/bin
LIBPATH="$LIBPATH":"$JAVA_HOME"/bin/classic
LIBPATH="$LIBPATH":"$JZOS_HOME"

if [ -n "$DB2_HOME" ] ; then
    export LD_LIBRARY_PATH="$LD_LIBRARY_PATH":"$DB2_HOME"/lib
    LIBPATH="$LIBPATH":"$DB2_HOME"/lib
    export DB2SQLJPROPERTIES="$DB2_HOME"/classes/db2sqljjdbc.properties    
fi
export LIBPATH="$LIBPATH":

# Configure CLASSPATH...

# Add $APP_HOME, $APP_HOME/*.jar, $APP_HOME/lib/*.jar to CLASSPATH
CLASSPATH=""
if [ -n "$APP_HOME" ] ; then
  CLASSPATH="$APP_HOME"
  for i in `ls $APP_HOME/*.jar 2> /dev/null`; do
    CLASSPATH="$CLASSPATH":"$i"
    done
  if [ -d "$APP_HOME"/lib ] ; then
    for i in `ls $APP_HOME/lib/*.jar 2> /dev/null`; do
      CLASSPATH="$CLASSPATH":"$i"
        done
  fi      
fi

# Add JZOS required jars to end of CLASSPATH
for i in "$JZOS_HOME"/*.jar; do
  CLASSPATH="$CLASSPATH":"$i"
  done
    
# If DB2_HOME set, add DB2 JDBC jar to end of CLASSPATH and set DB2SQLJPROPERTIES
if [ -n "$DB2_HOME" ] ; then
  CLASSPATH="$CLASSPATH":"$DB2_HOME"/classes/db2j2classes.zip
  export DB2SQLJPROPERTIES="$DB2_HOME"/classes/db2sqljjdbc.properties    
fi
 
export CLASSPATH="$CLASSPATH":

# Set JZOS specific options
# Use this variable to specify encoding for DD STDOUT and STDERR
#export JZOS_OUTPUT_ENCODING=Cp1047
# Use this variable to prevent JZOS from handling MVS operator commands
#export JZOS_ENABLE_MVS_COMMANDS=false
# Use this variable to supply additional arguments to main
#export JZOS_MAIN_ARGS=""

# Configure IBM_JAVA_OPTIONS...

# Configure min and max heap settings, if not overridden
# >>> Customize default min/max heap sizes below for your installation
if [ -z "$JAVA_MIN_HEAP" ] ; then
  JAVA_MIN_HEAP="16m"
fi 
if [ -z "$JAVA_MAX_HEAP" ] ; then
  JAVA_MAX_HEAP="128m"
fi 

IJO="-Xms$JAVA_MIN_HEAP -Xmx$JAVA_MAX_HEAP"

export IBM_JAVA_OPTIONS="$IJO "
